==> 1.4.7.tar.gz: bfcommonkit/BFCommonKit/Classes/BFUtility/PQConstant.swift <==
//
//  PQConstant.swift
//  PQSpeed
//
//  Created by SanW on 2020/5/25.
//  Copyright © 2020 BytesFlow. All rights reserved.
//

import Foundation
import Kingfisher
import UIKit

public let cScreenWidth: CGFloat = UIScreen.main.bounds.width
public let cScreenHeigth: CGFloat = UIScreen.main.bounds.height

//获取状态栏的高度，全面屏手机的状态栏高度为44pt，非全面屏手机的状态栏高度为20pt
//状态栏高度
public let statusBarHeight = UIApplication.shared.statusBarFrame.height;
//导航栏高度
public let navigationHeight = CGFloat(statusBarHeight + 44.0)
//tabbar高度
public let tabBarHeight = CGFloat(statusBarHeight > 20.0 ? 83.0 : 49.0)
//顶部的安全距离
public let topSafeAreaHeight = CGFloat(statusBarHeight - 20.0)
//底部的安全距离，全面屏手机为34pt，非全面屏手机为0pt
public let bottomSafeAreaHeight = CGFloat(tabBarHeight - 49.0)


// 屏幕适配系数  iponneX?
public let cAdaptatWidth = cScreenWidth / 375
public let cAdaptatHeigth = cScreenHeigth / 667
/// 图库大小
public let photoItemSize = CGSize(width: (cScreenWidth - cDefaultMargin) / 3, height: (cScreenWidth - cDefaultMargin) / 3) // cell 大小
// add by ak 视频制作工具视频画布大小
// 1:1
public let cVideoCannvasSizeOneToOne = CGSize(width: 1080.0, height: 1080.0)
// 16:9
public let cVideoCannvasSizeSixteenToNine = CGSize(width: 1920.0, height: 1080.0)
// 9:16
public let cVideoCannvasSizeNineToSixteen = CGSize(width: 1080.0, height: 1920.0)

// add by ak 声频 hz
public let cEditAudioSampleRate = 44100

// 获取安全区域大小
public let cSafeAreaHeight: CGFloat = cIPHONE_X() == true ? 34.0 : 0.0

// 获取安全区域大小
public let cAKSafeAreaHeight: CGFloat = cIPHONE_X() == true ? 25.0 : 0.0

public let cDevice_iPhoneStatusBarHei: CGFloat = cIPHONE_X() == true ? 44.0 : 20.0
public let cDevice_iPhoneNavBarHei: CGFloat = 44.0
public let cDevice_iPhoneNavBarAndStatusBarHei: CGFloat = cDevice_iPhoneStatusBarHei + cDevice_iPhoneNavBarHei
public let cDevice_iPhoneTabBarHei: CGFloat = cSafeAreaHeight + 49.0
// 遮罩颜色
public let cShadowColor: UIColor = UIColor(red: 0, green: 0, blue: 0, alpha: 0.5)
/// 通知
public let PQNotification: NotificationCenter = NotificationCenter.default

/** 默认间隔 */
public let cDefaultMargin: CGFloat = 10
// 时间精度
public let playerTimescale: Float64 = 1000.0
// 时间精度Ints
public let playerTimescaleInt: Int32 = 1000
// 最大上传大小 10G
public let maxUploadSize: Float64 = 10.0 * 1024.0 * 1024.0 * 1024.0
// 最大素材大小 500M
public let maxMartialSize: Float64 = 500.0 * 1024.0 * 1024.0
/// 音频频率范围值
public let cFrequency: [CGFloat] = [9.0, 12.0, 16.5, 18, 24, 21, 18, 16.5, 12, 16.5, 18, 16.5, 12]
/**************** tag *******************/

public let cCellTag: Int = 100_001
/** 引导 tag */
public let cGuideTag: Int = 100_002
/** 视频封面tag */
public let cCoverInfoTag: Int = 100_003
/** 协议tag */
public let cProtocalViewTag: Int = 100_004
/** 心形tag */
public let cHeartTag: Int = 100_005
/** 订阅提示tag */
public let cSubcribeRemindTag: Int = 100_006
/** 订阅提示tag */
public let cPushRemindTag: Int = 100_007
/** 活动提示tag */
public let cActivityRemindTag: Int = 100_008
/** pay提示tag */
public let cPayInfoTag: Int = 100_009
/** 绑定手机号提示tag */
public let cBandinPhoneTag: Int = 100_010
/// 上传最大viewTag
public let cUploadMaxCountRemindTag: Int = 100_011
/// 上传提示tag
public let cUploadViewRemindTag: Int = 100_012
/// 视频制作播放背景音乐的tag
public let cVideoMKBGMPlayTag: Int = 100_013
/// 上滑提示tag
public let cUpSlideViewRemindTag: Int = 100_014
/// 创作视频引导提示tag
public let cVideoMakeRemindTag: Int = 100_015
/// 操作弹出tag
public let cOprationRemindTag: Int = 100_016
/// 气泡提示视图tag
public let cBubbleRemindViewTag: Int = 100_017
/// 素材推荐提示tag
public let cRecommendMaterialViewTag: Int = 100_018
/// 气泡提示视图tag
public let cPageMaterialGuidTag: Int = 100_019
/// 信息流视频广告tag
public let cAdDrawVideoViewTag: Int = 100_020
/****************** 私有key ***************/

// 创作工具-项目id前缀
public let cProjectIdPrefix: String = "app_no_projectdata_"

public let cPrimarykey: String = "@taiziliudong_2020"
// ---
public let cRedEnvoStorageKey: String = "redEnvo\(cPrimarykey)"
public let cOriginStorageKey: String = "origin\(cPrimarykey)"
public let cZhiFStorageKey: String = "zhiF\(cPrimarykey)"
public let cCoinStorageKey: String = "coin\(cPrimarykey)"
public let cMoneStorageKey: String = "mone\(cPrimarykey)"
public let cAccouStorageKey: String = "accou\(cPrimarykey)"
public let cTasStorageKey: String = "tas\(cPrimarykey)"
public let cGameStorageKey: String = "game\(cPrimarykey)"
public let cSepraStorageKey: String = "sepra\(cPrimarykey)"
public let cFreeStorageKey: String = "free\(cPrimarykey)"
public let cRedImageStorageKey: String = "ic_hbs_enter\(cPrimarykey)"
public let cNewImageStorageKey: String = "icon_hbs_free\(cPrimarykey)"
// 当前Tab
public let cCurrentTabStorageKey: String = "currentTab\(cPrimarykey)"
// 用户信息key
public let cUserInfoStorageKey: String = "userInfo\(cPrimarykey)"
// 是否加载过引导页
public let cGuidedInfoStorageKey: String = "guidedInfo\(cPrimarykey)"
// 是否第一次安装
public let cFirstInstall: String = "firstInstall\(cPrimarykey)"
// 是否显示了用户信息收集
public let cShowUserInfoCollectInstall: String = "showUserInfoCollectInstall\(cPrimarykey)"
// 是否显示了感兴趣
public let cShowUserInterestedTopic: String = "showUserInterestedTopic\(cPrimarykey)"
// 第一次冷启动未上传参数
public let cFirstParams: String = "firstParams\(cPrimarykey)"

// 是否显示了协议
public let cShowProtocal: String = "showProtocal\(cPrimarykey)"

// 是否竖滑过
public let cIsVerticalSlip: String = "isVerticalSlip\(cPrimarykey)"
// 是否横滑过
public let cIsSideslip: String = "isSideslip\(cPrimarykey)"
// 是否在浏览态/操作态 单击过（不包含播放结束）
public let cIsSingleClick: String = "isSingleClick\(cPrimarykey)"
// 是否显示过竖滑提示
public let cIsVerticalSlipTip: String = "isVerticalSlipTip\(cPrimarykey)"
// 是否显示过竖滑提示
public let cIsSideslipTip: String = "isSideslipTip\(cPrimarykey)"
// 是否显示过单击提示
public let cIsSingleClickTip: String = "isSingleClickTip\(cPrimarykey)"
// 是否显示过单击提示
public let cIsLikeTip: String = "isLikeTip\(cPrimarykey)"
// 是否显示过横屏提示
public let cIsLandscapeTip: String = "isLandscapeTip\(cPrimarykey)"
// 是否点击过
public let cIsUploadClick: String = "isUploadClick\(cPrimarykey)"
// 当前选中的tab
public let cSelectedTabIndex: String = "selectedTabIndex\(cPrimarykey)"
// 登录用户当前视频数
public let cMineVideos: String = "mineVideos\(cPrimarykey)"
// 登录用户当前视频数
public let cMineFans: String = "mineFans\(cPrimarykey)"
// 别人订阅我的数量
public let cOtherSubscribes: String = "otherSubscribes\(cPrimarykey)"
/// 登录用户关注数
public let cMineIdols: String = "mineIdols\(cPrimarykey)"
// 登录用户头像
public let cAvatarUrl: String = "avatarUrl\(cPrimarykey)"
// 绑定手机号
public let cUpdatePhone: String = "updatePhone\(cPrimarykey)"
// 添加视频
public let cInsertVideo: String = "InsertVideo\(cPrimarykey)"
// 是否是新用户参加RedActivity
public let cIsNewRedActivityUser: String = "isNewRedActivityUser\(cPrimarykey)"
// 是否已经显示过昨天完成
public let cIsYesdayFinishRedActivity: String = "isYesdayFinishRedActivity\(cPrimarykey)"
// 是否已经显示过未完成昨天RedActivity
public let cIsYesdayNoFinishRedActivity: String = "isYesdayNoFinishRedActivity\(cPrimarykey)"
// 是否已经显示过今日已完成
public let cIsTodayFinishRedActivity: String = "isTodayFinishRedActivity\(cPrimarykey)"
// 是否已经显示过我的制作提示
public let cIsShowDraftBoxEntranceRemind: String = "isShowDraftBoxEntranceRemind\(cPrimarykey)"
// 是否展示过定位提醒
public let cIsShoWedLocationView: String = "isShoWedLocationView\(cPrimarykey)"
// 是否展示编辑封面提示
public let cIsShoWedEditCoverRemindView: String = "isShoWedEditCoverRemindView\(cPrimarykey)"
// 创作工具是否添加音乐去预览时提示
public let cIsShoWedAddBGMPreRemindView: String = "isShoWedAddBGMPreRemindView\(cPrimarykey)"
// 创作工具添加音乐提示
public let cShoWedAddBGMRemindView: String = "shoWedAddBGMRemindView\(cPrimarykey)"
// 刷新已读数
public let cUpdateMsgNoReadCount: String = "updateMsgNoReadCount\(cPrimarykey)"

// add by ak 是否显示过裁剪引导
public let cIsShowImageCropGuid: String = "isShowImageCropGuid\(cPrimarykey)"
// 编辑界面引导是否显示过 add by ak
public let cEditPageGuidIsShow: String = "cEditPageGuidIsShow\(cPrimarykey)"
// 画布引导
public let cEditPageCanvasGuidIsShow: String = "cEditPageCanvasGuidIsShow\(cPrimarykey)"
// 素材移动引导
public let cEditPageMaterialGuidIsShow: String = "cEditPageMaterialGuidIsShow\(cPrimarykey)"
// ******************* 通知key ******************* //
// 消息二级已读通知
public let cMsgTheTypeReadedNotiKey: String = "msgTheTypeReadedNoti\(cPrimarykey)"
// 话题订阅刷新
public let cRefreshTopicListNotiKey: String = "refreshTopicListNoti\(cPrimarykey)"
// 点赞刷新
public let cRefreshPraiseNotiKey: String = "refreshPraiseNoti\(cPrimarykey)"
// 关注
public let cAttendtionNotiKey: String = "attendtionNoti\(cPrimarykey)"
// 订阅
public let cSubscribeNotiKey: String = "subscribeNoti\(cPrimarykey)"
// 加入黑名单
public let cBannedNotiKey: String = "bannedNoti\(cPrimarykey)"
// 喜欢
public let cFavoriteNotiKey: String = "favoriteNoti\(cPrimarykey)"
// 退出登录
public let cQuitSuccesssNotiKey: String = "quitSuccesssNoti\(cPrimarykey)"
// 登录成功
public let cLoginSuccesssNotiKey: String = "loginSuccesssNoti\(cPrimarykey)"
// 更新用户数据
public let cUpdateInfoNotiKey: String = "updateInfoNoti\(cPrimarykey)"
// 是否显示手机登录 1-显示 0-不显示
public let cNeedLoginKey: String = "needLogin\(cPrimarykey)"
// 发布视频成功通知
public let cPublishSuccessKey: String = "publishSuccess\(cPrimarykey)"
// 发布视频成功开始分享通知
public let cPublishOrUpdateSuccessToShareKey: String = "publishOrUpdateSuccessToShareKey\(cPrimarykey)"
// 发布卡点视频成功通知
public let cPublishStuckPointSuccessKey: String = "publishStuckPointSuccess\(cPrimarykey)"
public let cUploadSuccessKey: String = "uploadSuccess\(cPrimarykey)"
/// 更新视频成功
public let cUpdateVideoSuccessKey: String = "updateVideoSuccess\(cPrimarykey)"
/// 绑定手机号成功的通知
public let cBandingPhoneSuccessKey: String = "bandingPhoneSuccessKey\(cPrimarykey)"
/// 图库添加图片的通知
public let cSelectedImageSuccessKey: String = "selectedImageSuccess\(cPrimarykey)"
/// 删除视频的通知
public let cDeleteVideoSuccessKey: String = "deleteVideoSuccess\(cPrimarykey)"
/// 导出背景音乐成功的通知
public let cExportBGMAudioSuccessKey: String = "exportBGMxAudioSuccess\(cPrimarykey)"
/// 下载资源成功/失败的key
public let cDownloadMatrialSuccessKey: String = "downloadMatrialSuccess\(cPrimarykey)"
/// 素材处理成功key
public let cVideoDealWithSuccessKey: String = "videoDealWithSuccess\(cPrimarykey)"
/// 话题订阅状态改变时通知
public let cTopicSubscribeStatusChangedKey: String = "topicSubscribeStatusChanged\(cPrimarykey)"

/// 批量下载资源成功/失败的key
public let cBatchDownloadMatrialSuccessKey: String = "batchDownloadMatrialSuccess\(cPrimarykey)"
/// 批量上传资源成功/失败的key
public let cBatchUploadMatrialSuccessKey: String = "batchUploadMatrialSuccessKey\(cPrimarykey)"
/// 再创作成功的key
public let cReCreateVideoSuccessKey: String = "reCreateVideoSuccess\(cPrimarykey)"
/// 收藏/取消背景音乐的通知
public let cFavoriteBgmKey: String = "favoriteBgm\(cPrimarykey)"
/// 保存素材成功通知
public let cSaveMaterialSuccessKey: String = "saveMaterialSuccess\(cPrimarykey)"
/// 音频素材转换成文字成功
public let cAudioTransferSubTitleSuccessKey: String = "audioTransferSubTitleSuccess\(cPrimarykey)"
/// 无网
public let cLostNet: String = "lostNet\(cPrimarykey)"
// 取消视频发布引导弹框
public let cDismissVideoMakeGuideKey: String = "dismissVideoMakeGuide\(cPrimarykey)"
// 点击完成或发布完成跳转
public let cFinishedPublishedNotiKey: String = "finishedPublishedNotiKey\(cPrimarykey)"

// oss 上传文件进度 add by ak
public let cOSSUploadFileProgress: String = "OSSUploadFileProgress\(cPrimarykey)"

// 渠道
public let channelID = "AppStore"
// 推送渠道
public let cPushChannel = "APPLE_TYPE"

// MARK: 账号

// 友盟账号
public let cUMAppkey: String = "5ee4a806978eea081640dfe4"
// bugly账号
public let cBuglyAppkey: String = "39065c15d0"
// 阿里反馈账号
public let cAliFeedbackAppkey: String = "23591190"
// 阿里反馈AppSecret
public let cAliFeedbackAppSecret: String = "3b831b2068aef36607886a3912ef4fbb"
// 百度定位key
public let cBMKLocationAppkey: String = "buprQzBBojKbvDvED8Xix7xHA91ShAnL"
// 分享小程序ID
public let cShareWeappRawId: String = "gh_ecd1ea0b84cf"

==> 1.6.0.tar.gz: bfcommonkit/BFCommonKit/Classes/BFUtility/PQConstant.swift <==
//
//  PQConstant.swift
//  PQSpeed
//
//  Created by SanW on 2020/5/25.
//  Copyright © 2020 BytesFlow. All rights reserved.
//

import Foundation
import Kingfisher
import UIKit

/// 通知
public let PQNotification: NotificationCenter = NotificationCenter.default

/// ** 默认间隔 */
// public let cDefaultMargin: CGFloat = 10
// 时间精度
public let playerTimescale: Float64 = 1000.0
// 时间精度Ints
public let playerTimescaleInt: Int32 = 1000
// 最大上传大小 10G
public let maxUploadSize: Float64 = 10.0 * 1024.0 * 1024.0 * 1024.0
// 最大素材大小 500M
public let maxMartialSize: Float64 = 500.0 * 1024.0 * 1024.0
/// 音频频率范围值
public let cFrequency: [CGFloat] = [9.0, 12.0, 16.5, 18, 24, 21, 18, 16.5, 12, 16.5, 18, 16.5, 12]

/****************** 私有key ***************/

// 创作工具-项目id前缀
public let cProjectIdPrefix: String = "app_no_projectdata_"

public let cPrimarykey: String = "@taiziliudong_2020"
// ---
public let cRedEnvoStorageKey: String = "redEnvo\(cPrimarykey)"
public let cOriginStorageKey: String = "origin\(cPrimarykey)"
public let cZhiFStorageKey: String = "zhiF\(cPrimarykey)"
public let cCoinStorageKey: String = "coin\(cPrimarykey)"
public let cMoneStorageKey: String = "mone\(cPrimarykey)"
public let cAccouStorageKey: String = "accou\(cPrimarykey)"
public let cTasStorageKey: String = "tas\(cPrimarykey)"
public let cGameStorageKey: String = "game\(cPrimarykey)"
public let cSepraStorageKey: String = "sepra\(cPrimarykey)"
public let cFreeStorageKey: String = "free\(cPrimarykey)"
public let cShouyyyStorageKey: String = "shouyyy\(cPrimarykey)"
public let cZhenmonennStorageKey: String = "zhenmonenn\(cPrimarykey)"
public let cRedImageStorageKey: String = "ic_hbs_enter\(cPrimarykey)"
public let cNewImageStorageKey: String = "icon_hbs_free\(cPrimarykey)"
// 当前Tab
public let cCurrentTabStorageKey: String = "currentTab\(cPrimarykey)"
// 用户信息key
public let cUserInfoStorageKey: String = "userInfo\(cPrimarykey)"
// 是否加载过引导页
public let cGuidedInfoStorageKey: String = "guidedInfo\(cPrimarykey)"
// 是否第一次安装
public let cFirstInstall: String = "firstInstall\(cPrimarykey)"
// 是否显示了用户信息收集
public let cShowUserInfoCollectInstall: String = "showUserInfoCollectInstall\(cPrimarykey)"
// 是否显示了感兴趣
public let cShowUserInterestedTopic: String = "showUserInterestedTopic\(cPrimarykey)"
// 第一次冷启动未上传参数
public let cFirstParams: String = "firstParams\(cPrimarykey)"
// 是否显示了协议
public let cShowProtocal: String = "showProtocal\(cPrimarykey)"
// 是否显示过热榜提示
public let cHotBoardRemindShowed: String = "hotBoardRemindShowed\(cPrimarykey)"
// 是否竖滑过
public let cIsVerticalSlip: String = "isVerticalSlip\(cPrimarykey)"
// 是否横滑过
public let cIsSideslip: String = "isSideslip\(cPrimarykey)"
// 是否在浏览态/操作态 单击过（不包含播放结束）
public let cIsSingleClick: String = "isSingleClick\(cPrimarykey)"
// 是否显示过竖滑提示
public let cIsVerticalSlipTip: String = "isVerticalSlipTip\(cPrimarykey)"
// 是否显示过竖滑提示
public let cIsSideslipTip: String = "isSideslipTip\(cPrimarykey)"
// 是否显示过单击提示
public let cIsSingleClickTip: String = "isSingleClickTip\(cPrimarykey)"
// 是否显示过单击提示
public let cIsLikeTip: String = "isLikeTip\(cPrimarykey)"
// 是否显示过横屏提示
public let cIsLandscapeTip: String = "isLandscapeTip\(cPrimarykey)"
// 是否点击过
public let cIsUploadClick: String = "isUploadClick\(cPrimarykey)"
// 当前选中的tab
public let cSelectedTabIndex: String = "selectedTabIndex\(cPrimarykey)"
// 登录用户当前视频数
public let cMineVideos: String = "mineVideos\(cPrimarykey)"
// 登录用户当前视频数
public let cMineFans: String = "mineFans\(cPrimarykey)"
// 别人订阅我的数量
public let cOtherSubscribes: String = "otherSubscribes\(cPrimarykey)"
/// 登录用户关注数
public let cMineIdols: String = "mineIdols\(cPrimarykey)"
// 登录用户头像
public let cAvatarUrl: String = "avatarUrl\(cPrimarykey)"
// 绑定手机号
public let cUpdatePhone: String = "updatePhone\(cPrimarykey)"
// 添加视频
public let cInsertVideo: String = "InsertVideo\(cPrimarykey)"
// 是否是新用户参加RedActivity
public let cIsNewRedActivityUser: String = "isNewRedActivityUser\(cPrimarykey)"
// 是否已经显示过昨天完成
public let cIsYesdayFinishRedActivity: String = "isYesdayFinishRedActivity\(cPrimarykey)"
// 是否已经显示过未完成昨天RedActivity
public let cIsYesdayNoFinishRedActivity: String = "isYesdayNoFinishRedActivity\(cPrimarykey)"
// 是否已经显示过今日已完成
public let cIsTodayFinishRedActivity: String = "isTodayFinishRedActivity\(cPrimarykey)"
// 是否已经显示过我的制作提示
public let cIsShowDraftBoxEntranceRemind: String = "isShowDraftBoxEntranceRemind\(cPrimarykey)"
// 是否展示过定位提醒
public let cIsShoWedLocationView: String = "isShoWedLocationView\(cPrimarykey)"
// 是否展示编辑封面提示
public let cIsShoWedEditCoverRemindView: String = "isShoWedEditCoverRemindView\(cPrimarykey)"
// 创作工具是否添加音乐去预览时提示
public let cIsShoWedAddBGMPreRemindView: String = "isShoWedAddBGMPreRemindView\(cPrimarykey)"
// 创作工具添加音乐提示
public let cShoWedAddBGMRemindView: String = "shoWedAddBGMRemindView\(cPrimarykey)"
// 刷新已读数
public let cUpdateMsgNoReadCount: String = "updateMsgNoReadCount\(cPrimarykey)"
// 今日已完成分享次数
public let cIsTodayFHShareActivity: String = "isTodayFHShareActivity\(cPrimarykey)"
// 今日是否显示过加入提示
public let cIsShowTodayJoinActivity: String = "isShowTodayJoinActivity\(cPrimarykey)"
// 是否取消显示限制
public let cIsNoForbiddenShareView: String = "isNoForbiddenShareView\(cPrimarykey)"
// add by ak 是否显示过裁剪引导
public let cIsShowImageCropGuid: String = "isShowImageCropGuid\(cPrimarykey)"
// 编辑界面引导是否显示过 add by ak
public let cEditPageGuidIsShow: String = "cEditPageGuidIsShow\(cPrimarykey)"
// 画布引导
public let cEditPageCanvasGuidIsShow: String = "cEditPageCanvasGuidIsShow\(cPrimarykey)"
// 素材移动引导
public let cEditPageMaterialGuidIsShow: String = "cEditPageMaterialGuidIsShow\(cPrimarykey)"
// ******************* 通知key ******************* //
// 消息二级已读通知
public let cMsgTheTypeReadedNotiKey: String = "msgTheTypeReadedNoti\(cPrimarykey)"
// 话题订阅刷新
public let cRefreshTopicListNotiKey: String = "refreshTopicListNoti\(cPrimarykey)"
// 点赞刷新
public let cRefreshPraiseNotiKey: String = "refreshPraiseNoti\(cPrimarykey)"
// 关注
public let cAttendtionNotiKey: String = "attendtionNoti\(cPrimarykey)"
// 订阅
public let cSubscribeNotiKey: String = "subscribeNoti\(cPrimarykey)"
// 加入黑名单
public let cBannedNotiKey: String = "bannedNoti\(cPrimarykey)"
// 喜欢
public let cFavoriteNotiKey: String = "favoriteNoti\(cPrimarykey)"
// 退出登录
public let cQuitSuccesssNotiKey: String = "quitSuccesssNoti\(cPrimarykey)"
// 登录成功
public let cLoginSuccesssNotiKey: String = "loginSuccesssNoti\(cPrimarykey)"
// 更新用户数据
public let cUpdateInfoNotiKey: String = "updateInfoNoti\(cPrimarykey)"
// 是否显示手机登录 1-显示 0-不显示
public let cNeedLoginKey: String = "needLogin\(cPrimarykey)"
// 发布视频成功通知
public let cPublishSuccessKey: String = "publishSuccess\(cPrimarykey)"
// 发布视频成功开始分享通知
public let cPublishOrUpdateSuccessToShareKey: String = "publishOrUpdateSuccessToShareKey\(cPrimarykey)"
// 发布卡点视频成功通知
public let cPublishStuckPointSuccessKey: String = "publishStuckPointSuccess\(cPrimarykey)"
public let cUploadSuccessKey: String = "uploadSuccess\(cPrimarykey)"
/// 更新视频成功
public let cUpdateVideoSuccessKey: String = "updateVideoSuccess\(cPrimarykey)"
/// 绑定手机号成功的通知
public let cBandingPhoneSuccessKey: String = "bandingPhoneSuccessKey\(cPrimarykey)"
/// 图库添加图片的通知
public let cSelectedImageSuccessKey: String = "selectedImageSuccess\(cPrimarykey)"
/// 删除视频的通知
public let cDeleteVideoSuccessKey: String = "deleteVideoSuccess\(cPrimarykey)"
/// 导出背景音乐成功的通知
public let cExportBGMAudioSuccessKey: String = "exportBGMxAudioSuccess\(cPrimarykey)"
/// 下载资源成功/失败的key
public let cDownloadMatrialSuccessKey: String = "downloadMatrialSuccess\(cPrimarykey)"
/// 素材处理成功key
public let cVideoDealWithSuccessKey: String = "videoDealWithSuccess\(cPrimarykey)"
/// 话题订阅状态改变时通知
public let cTopicSubscribeStatusChangedKey: String = "topicSubscribeStatusChanged\(cPrimarykey)"
/// 发布页最近加入的话题
public let cPublicLastJoinTopicInfoKey: String = "publicLastJoinTopicInfoKey\(cPrimarykey)"

/// 批量下载资源成功/失败的key
public let cBatchDownloadMatrialSuccessKey: String = "batchDownloadMatrialSuccess\(cPrimarykey)"
/// 批量上传资源成功/失败的key
public let cBatchUploadMatrialSuccessKey: String = "batchUploadMatrialSuccessKey\(cPrimarykey)"
/// 再创作成功的key
public let cReCreateVideoSuccessKey: String = "reCreateVideoSuccess\(cPrimarykey)"
/// 收藏/取消背景音乐的通知
public let cFavoriteBgmKey: String = "favoriteBgm\(cPrimarykey)"
/// 保存素材成功通知
public let cSaveMaterialSuccessKey: String = "saveMaterialSuccess\(cPrimarykey)"
/// 音频素材转换成文字成功
public let cAudioTransferSubTitleSuccessKey: String = "audioTransferSubTitleSuccess\(cPrimarykey)"
/// 无网
public let cLostNet: String = "lostNet\(cPrimarykey)"
// 取消视频发布引导弹框
public let cDismissVideoMakeGuideKey: String = "dismissVideoMakeGuide\(cPrimarykey)"
// 点击完成或发布完成跳转
public let cFinishedPublishedNotiKey: String = "finishedPublishedNotiKey\(cPrimarykey)"

// oss 上传文件进度 add by ak
public let cOSSUploadFileProgress: String = "OSSUploadFileProgress\(cPrimarykey)"
// 渠道
public let channelID = "AppStore"
// 推送渠道
public let cPushChannel = "APPLE_TYPE"

// MARK: 账号

// 友盟账号
public let cUMAppkey: String = "5ee4a806978eea081640dfe4"
// bugly账号
public let cBuglyAppkey: String = "39065c15d0"
// 阿里反馈账号
public let cAliFeedbackAppkey: String = "23591190"
// 阿里反馈AppSecret
public let cAliFeedbackAppSecret: String = "3b831b2068aef36607886a3912ef4fbb"
// 百度定位key
public let cBMKLocationAppkey: String = "buprQzBBojKbvDvED8Xix7xHA91ShAnL"
// 分享小程序ID
public let cShareWeappRawId: String = "gh_ecd1ea0b84cf"
